@@ -31,8 +31,7 @@
 
 #include <gdk/gdk.h>
 #include <gtk/gtkbin.h>
-
-
+#include <gtk/gtkenums.h>
 
 G_BEGIN_DECLS
 
@@ -80,8 +79,8 @@ struct _BonoboDockItem
   /* Position of the floating window.  */
   gint16                  float_x, float_y;
 
-  BonoboDockItemBehavior behavior : 5;
-  GtkOrientation        orientation : 1;
+  guint                 behavior : 5;
+  guint                 orientation : 1;
 
   guint                 float_window_mapped : 1;
   guint                 is_floating : 1;
@@ -102,6 +101,8 @@ struct _BonoboDockItemClass
   void (* dock_drag_end) (BonoboDockItem *item);
   void (* dock_detach) (BonoboDockItem *item);
   void (* orientation_changed) (BonoboDockItem *item, GtkOrientation new_orientation);
+
+  gpointer dummy[4];
 };
 
 /* Public methods.  */
@@ -131,17 +132,20 @@ BonoboDockItemBehavior
 
 /* Private methods.  */
 #ifdef BONOBO_UI_INTERNAL
+void           bonobo_dock_item_set_locked      (BonoboDockItem *dock_item,
+						 gboolean        locked);
 gboolean       bonobo_dock_item_detach          (BonoboDockItem *item,
-                                                gint x, gint y);
+						 gint x, gint y);
                                                
 void           bonobo_dock_item_attach          (BonoboDockItem *item,
-                                                GtkWidget *parent,
-                                                gint x, gint y);
-                                               
+						 GtkWidget *parent,
+						 gint x, gint y);
+void           bonobo_dock_item_unfloat         (BonoboDockItem *item);
+
 void           bonobo_dock_item_grab_pointer    (BonoboDockItem *item);
                                                
 void           bonobo_dock_item_drag_floating   (BonoboDockItem *item,
-                                                gint x, gint y);
+						 gint x, gint y);
 
 void           bonobo_dock_item_handle_size_request
                                                (BonoboDockItem *item,
@@ -150,6 +154,8 @@ void           bonobo_dock_item_handle_size_request
 void           bonobo_dock_item_get_floating_position
                                                (BonoboDockItem *item,
                                                 gint *x, gint *y);
+GtkWidget     *bonobo_dock_item_get_grip       (BonoboDockItem *item);
+
 #endif /* BONOBO_UI_INTERNAL */
 
 G_END_DECLS
